/*********************************************************************
   LAN-XFER.c
   Purpose: copy a file for RBBS on a LAN system using PROTO.DEF template
   Note: needs two parameters:
	  the first parameter is a "d" for download or a "u" for upload
	  the second parameter is called FILE by RBBS and is the file
	   name used by RBBS for an upload or download.  On the user's end the
	   filename will be different.
   by: Geoffrey W. McNamara
   ver 1.00 released 7/18/90.
   see accompanying text files for more history detail
************************************************************************/

#include "stdio.h"
#include "stdlib.h"
#include "string.h"
#include <fcntl.h>
#include <alloc.h>
#include <io.h>
#include "dir.h"
#include <conio.h>
#include <mem.h>
#include <assert.h>
#include "window.h"
#include "_window.h"
#include <sys\types.h>
#include <sys\stat.h>
#include <dos.h>


/*** define statements - modify as you need ***/
#define VER "1.04 "
#define REL_DATE "09/07/90"
#define dfltpath "C:\\TEMP"  /* default path - should be in CAPs for consistency */
#define acceptdrive "A:B:C:D:" /* acceptable drives for workstations */
#define MAXWIN 6
#define TRUE 1

/*** global variable(s) ***/
char fname[80]="\0";
char msg[1][80];

windowtype *windowchain = NULL;
static unsigned int xpos, ypos;
windowtype *window_no[MAXWIN];

enum {TopLine, BottomLine, TopLeft, TopRight, BotLeft, BotRight,
		RightLine, LeftLine } _box;

static unsigned char style[][8] =
	{	{ '-',	'-',	'+'   , '+'   , '+'   , '+'   , '|',	'|'	}, /* just as you see them */
		{ '\xC4', '\xC4', '\xDA', '\xBF', '\xC0', '\xD9', '\xB3', '\xB3' },/* single line */
		{ '\xCD', '\xCD', '\xC9', '\xBB', '\xC8', '\xBC', '\xBA', '\xBA' },/* double line */
		{ '\xC4', '\xCD', '\xDA', '\xB7', '\xD4', '\xBC', '\xB3', '\xBA' } /* simple shadow, right&bottom */
		};

extern enum windowerrtype windowerr = WE_OK;
char pathname[MAXPATH], drive[MAXDRIVE], dir[MAXDIR], filename[MAXFILE], ext[MAXEXT];


/**************************************
MAIN program code
***************************************/
void main(int argc, char *argv[])
{
	/*** variable declarations ***/
/*	FILE  *src, *dest; */
	int i;

	/*** function declaration(s) ***/
	long OverWrite();
	void is_space_avail();
	int CopyFile(); /*** int function doesn't really need to be declared ***/
	char *GetFilename();
	void error_window();
	void bad_first_argv();
	void program_info();
	void close_out();
	char make_upper_case();

	/*** MAIN body ***/

	textattr(CYAN+(BLACK<<4));
	clrscr();

	/* check command line arguments */
	if(argc!=3)
	{
		fnsplit(argv[0],drive,dir,filename,ext);
		strcpy(msg[1]," Usage: ");
		make_upper_case(filename);
		strcat(msg[1], filename);
		strcat(msg[1], " u/d FILE ");
		error_window(" ERROR Syntax ", msg[1],1);
	}

	GetFilename(argv[2],argv[1]);  /*** get remote filename ***/

	switch (tolower(*argv[1]))	 /*** switch based on command line arg# 1 ***/
	{
		case 'd':	/*** download of file requested ***/
		{
			 is_space_avail( argv[2], fname, OverWrite(fname) );
			 CopyFile( argv[2], fname );  /*** Copy file over to remote ***/
			 break;
		}

		case 'u':	/*** upload requested ***/
		{
			is_space_avail(fname, argv[2], 0L );
			CopyFile( fname, argv[2] );   /*** Copy file from remote ***/
			break;
		}	/* end case argv[1]='u' */

		default:	/*** if command line argument[1] is wrong ***/
		{
			bad_first_argv();
			break;
		}

	} /*** end of switch ***/

	program_info();
	close_out();


} /*** end of main ***/

/******************************************************
		     Functions
*******************************************************/

/*********
FUNCTION: make_upper_case()
************/
char make_upper_case(char *string)
{
	int i;

	for(i=0;(string[i] !=' ')&&(string[i]!='\0');i++)
	{
	     string[i]=toupper(string[i]);
	}
	return(*string);
}

/**********
FUNCTION: error_window()
***********/
void error_window(char *error_title, char *error_msg, int fatal_flag)
/* fatal flag tells this function whether to exit() or just return
	0 = non-fatal	1 = fatal
   this function only allows one line error_msgs of 76 char */
{
	int startxpos, endxpos, msglen;

	msglen=strlen(error_msg);
	startxpos=40-(msglen/2+1);
	endxpos=40+(msglen/2);
	makewindow(startxpos,10,endxpos,10,RED+(LIGHTGRAY<<4),2,error_title);
	textattr(BLACK+(LIGHTGRAY<<4));
	cprintf("%s",error_msg);
	if(fatal_flag==1)
	{
		close_out();
		exit(0);
	}
}


/**************
FUNCTION: is_space_avail()
************/
void is_space_avail(char *src, char *dest, long ow_filesize)
{
	FILE *source;
	long filesize, diskspace, space_needed;
	long disk_space();

		/*** test for source file size fit ***/
	if((source=fopen(src,"r"))==NULL)
	{
		error_window(" ERROR Opening File "," Error opening source file.",1);
	}

	if( (filesize=filelength(fileno(source)))==-1L)
	{
		error_window(" ERROR File Length ", " Error getting file length",1);
	}

	fclose(source);
	space_needed=filesize-ow_filesize;
	fnsplit(dest,drive,dir,filename,ext);
	diskspace=disk_space(toupper(drive[0])-64,1);

	if( (space_needed>diskspace)==TRUE )
	{
		makewindow(5,10,70,11,RED+(LIGHTGRAY<<4),2," ERROR Available Disk Space ");
		textattr(BLACK+(LIGHTGRAY<<4));
		cprintf(" Insufficient destination disk space available for file transfer\n\r");
		cprintf("    Needed space = %ld   Available disk space = %ld",space_needed, diskspace);
		close_out();
		exit(1);
	}
}

/***********************
FUNCTION: OverWrite(fil)
	returns size of file to be overwritten
************************/
long OverWrite(char *fil)
{
	FILE *file;
	int i, length;
	long ow_filesize=0L;
	char overwriteYN;
	int Exists(), xpos, ypos;
	char make_upper_case();

	make_upper_case(fil);

	if (Exists(fil))
	{
		length=40+strlen(fil);
		window_no[2]=makewindow((40-(length/2)),14,(40+(length/2)),14,RED+(LIGHTGRAY<<4),2," Overwrite? ");
		textattr(WHITE+(LIGHTGRAY<<4));
		cprintf(" Overwrite the existing file ");
		textattr(BLACK+(LIGHTGRAY<<4));
		cprintf("< %s >? ",fil);
		textattr(WHITE+(LIGHTGRAY<<4));

		xpos=wherex();
		ypos=wherey();
		printf("%s","   ");
		gotoxy(xpos,ypos);
		textattr(WHITE+(BLACK<<4));
		printf("%s","No"); /* Still deciding whether to keep this or not */
		gotoxy(xpos,ypos);

		overwriteYN=getch();

		if (toupper(overwriteYN)!='Y')
		{
			cprintf("No");
			close_out();
			exit(1);
		}
		else
		{
			cprintf("Yes");
			if((file=fopen(fil,"r"))==NULL)
			{
				error_window(" ERROR Opening * File ", " Error in opening source file for status info...", 1);
			}
			if((ow_filesize=filelength(fileno(file)))==-1L)
			{
				error_window(" ERROR File Length ", " Error obtaining file length", 1);
			}
			fclose(file);
			return(ow_filesize);
		}
	}
	else
	{
		return(0);
	}  /*** end if Exists ***/
}  /*** end OverWrite() ***/

/**************************
FUNCTION: GetFilename()
***************************/
char *GetFilename(char *remotefile, char *ud_flag)
{
	char pathname[MAXPATH], drive[MAXDRIVE], dir[MAXDIR], filename[MAXFILE], ext[MAXEXT];
	char filetype[12];
	char reason[12];
	int xpos, ypos;
	char make_upper_case();

	if (tolower(*ud_flag)=='d')
	{
		strcpy(filetype,"destination");
		strcpy(reason,"downloading");
		strcpy(msg[1]," 			       ");
	   /* this msg[1] is a slightly different length from the one below */
	}
	if (tolower(*ud_flag)=='u')
	{
			strcpy(filetype,"source");
			strcpy(reason,"uploading");
			strcpy(msg[1]," 				    ");
	   /* this msg[1] is a slightly different length from the one above */
	}
	if (tolower(*ud_flag)!='u'&&tolower(*ud_flag)!='d')
	{
		bad_first_argv();
	}

	fnsplit(remotefile, drive, dir, filename, ext);
	make_upper_case(strcat(fname,filename));
	make_upper_case(strcat(fname,ext));

	window_no[1]=makewindow(2,10,78,13,(LIGHTBLUE+(LIGHTGRAY<<4)),2," Enter Filename ");
	textattr(WHITE+(LIGHTGRAY<<4));
	cprintf(" Please enter the %s drive:\\path\\filename.ext for %s.\n\r",filetype,reason);
	cprintf(" Just hit <ENTER> to default to: ");
	textattr(BLACK+(LIGHTGRAY<<4));
	cprintf("< %s\\%s >\n\r\n\r",dfltpath,fname);
	strcpy(fname,"\0"); /* reset fname = blank */
	textattr(WHITE+(LIGHTGRAY<<4));
	cprintf(" Your %s drive:\\path\\filename.ext: ",filetype);
	textattr(BLUE+(LIGHTGRAY<<4));

	xpos=wherex();
	ypos=wherey();
	printf("%s",msg[1]);
	gotoxy(xpos,ypos);
	textattr(WHITE+(BLACK<<4));

	gets(fname);

		  /* if fname is blank this will
		   * assign "c:\temp\FILE" to fname. It will make
		   * the dfltpath subdirectory if needed.
		   */

		if (fname[0]=='\0')
		{
			mkdir(dfltpath);
			strcat(fname,dfltpath);
			strcat(fname,"\\");
			fnsplit(remotefile, drive, dir, filename, ext);
			strcat(fname,filename);
			strcat(fname,ext);
		} /* end if */
		else
		{
			strcpy(drive,"\0");  /* reset drive = blank */
			fnsplit(fname, drive, dir, filename, ext);
			if(strstr(acceptdrive,strupr(drive))==0)
			{
				strcpy(msg[1]," Invalid drive assignment ");
				strcat(msg[1],drive);
				strcat(msg[1]," for ");
				strcat(msg[1], filetype);
				strcat(msg[1], " file. ");
				error_window(" ERROR Drive Assignment ", msg[1], 1);
			}
		} /* end else */
	return(fname);
} /*** end GetFilename() ***/

/*******************
FUNCTION: CopyFile()
********************/
int CopyFile( char *src, char *dest )
{
	int fd1, fd2, num, length;
	char *buffer;
	unsigned long numxferred=0;
	char make_upper_case();

	if ( ( buffer = (char *) calloc( 32001, 1 ) ) == NULL ) {
		strcpy(msg[1]," Not enough memory for transfer buffer.");
		error_window(" ERROR Memory ", msg[1], 1);
		/*** if not enough memory to allocate ***/
	}


	if ( ( fd1 = open( src, O_RDONLY | O_BINARY ) ) == EOF ) {
		free( buffer );
		error_window(" ERROR File not Found ", " Source file not found. ",1);
		/*** if source file not found or not successfully opened ***/
	}


	if ( ( fd2 = _creat( dest, 0 ) ) == EOF ) {
		free( buffer );
		error_window(" ERROR File Opening ", " Destination file not successfully opened.",1);
		/*** if dest file not successfully opened ***/
	}

		/*** if all goes well strat transfer (copy)  ***/
		length=(strlen(src)+strlen(dest)+14);
		if ((length<41)==TRUE)
		{
			length=41;
		}
		window_no[3]=makewindow((40-(length/2)),16,(40+(length/2)),18,LIGHTBLUE+(LIGHTGRAY<<4),2," Transferring file ");
		textattr(WHITE+(LIGHTGRAY<<4));
		gotoxy( ((length-39) /2) ,1);
		cprintf(" Transferring a copy of requested file:");
		textattr(BLACK+(LIGHTGRAY<<4));
		make_upper_case(src);
		if( (length<42) ==TRUE)
		{
			gotoxy( (((strlen(src)+strlen(dest))+7)/2) , 2);
		}
		else
		{
			gotoxy(1,2);
		}
		cprintf(" < %s >",src);
		textattr(WHITE+(LIGHTGRAY<<4));
		cprintf(" to ");
		textattr(BLACK+(LIGHTGRAY<<4));
		cprintf("< %s >",dest);

	while ( ( num = read( fd1, buffer, 32000 ) ) > 0 ) {
		if ( num != write( fd2, buffer, num ) ) /*** if error on writing to dest file ***/
			{
			error_window(" ERROR Writing File ", " Error trying to write to destination file.",1);
			}
		else
		{
			numxferred = numxferred+num;
			gotoxy( ((length-28)/2) ,3);
			textattr(WHITE+(LIGHTGRAY<<4));
			cprintf("Bytes transferred = ");
			textattr(BLACK+(LIGHTGRAY<<4));
			cprintf("%ld",numxferred); /*** if transfer ok ***/
		}
	}

	close( fd2 );
	close( fd1 );
	free( buffer );
	return( 0 );
}

/*************
FUNCTION: Exists()
*************/
int Exists( char *filename )
{
	return( access( filename, 0 ) == 0 );
}

/***************
FUNCTION bad_first_argv()
***************/
void bad_first_argv()
{
	char msg[]=" 1st parameter apparently not \"d\" or \"u\"";
	error_window(" ERROR with first argument ", msg, 1);
	close_out();
	exit(1);
}

/**********************
FUNCTION program_info()
***********************/
void program_info()
{
	makewindow(40,22,78,23,BLUE+(LIGHTGRAY<<4),2," Program Information ");
	textattr(BLACK+(LIGHTGRAY<<4));
	cprintf(" LAN-XFER ver: %s released %s\n\r       by: Geoffrey W. McNamara ",VER,REL_DATE);
}

/***********
FUNCTION close_out()
********/
void close_out()
{
	int i;
	for (i=1; i<MAXWIN+1; i++)
	{
		if (window_no[i]!=NULL)
		{
			delay(650);
			shiftwindow(window_no[i]);
			deletewindow(window_no[i]);
		}
	}
	window(1,1,80,25);
	gotoxy(1,23);
}

/***************
FUNCTION:  box()
*****************/
static void box(unsigned char left, unsigned char top, unsigned char right,
		unsigned char bottom, char pattr, unsigned char *boxchars)
{
	unsigned int tmp1, tmp2, attr = pattr << 8;
	int width, size, i;
	unsigned int *box;

	if ( (box = malloc( (size = (right-left+1)*(bottom-top+1))*2 )) == NULL )
		return;

	box[0] =  ' ' | attr;

	/* Ripple move the space with current attribute to the entire block */
	/* This routine depends on memcpy not copying overlapping blocks
	 * correctly in the forward direction and two bytes at a time.
	 */
	memcpy(&box[1],box,size<<1);

	/* Top line */
	box[0] = boxchars[TopLeft] | attr;
	box[ ((width = right - left + 1) - 1) ] = boxchars[TopRight] |
		attr;

	box[1] = boxchars[TopLine] | attr;

	/* Ripple move - see above */
	memcpy(&box[2],&box[1],(width-3)<<1);

	tmp1 = boxchars[LeftLine]  | attr;
	tmp2 = boxchars[RightLine] | attr;
	for (i = width; i<size-width; i += width)
	{
		box[i+width-1]	= tmp1;
		box[i]			= tmp2;
	}

	box[i] = boxchars[BotLeft] | attr;
	box[i+width-1] = boxchars[BotRight] | attr;

	box[i+1] = boxchars[BottomLine] | attr;

	/* Ripple move - see above */
	memcpy(&box[i+2],&box[i+1],(width-3)<<1);
	puttext(left,top,right,bottom,box);

	free(box);
}

/****************
FUNCTION:  makewindow()
**********************/
/*   Open a window on the screen.  It becomes the current window.
 *   RETURNS: 0 Success, 1 Out of memory, 2 Bad coordinates.
 *   Coordinates must range from 2-79,2-24 (allow for the border).
 *   Attrib: 1=    2=	  3=	4=    5=    6=	  7=
 *   Styles: 0 use low-bit graphics chars, 1 single line, 2 double line,
 *   3 simple shadow, right & bottom.
 */
windowtype *makewindow( unsigned char  left, unsigned char  top, unsigned char	right,
			unsigned char  bottom, char attr, unsigned char the_style,
			char *title)
{
	windowtype *current;
	int size, len;

	windowerr = WE_OK;

	invalidate_backimage();

	/* Check the coordinates */
	if (top < 2 || bottom > 24 || left < 2 || right > 79 || top > bottom
		|| left > right)
	{
		windowerr = WE_BADC;
		return NULL;
	}

	/* Allocate the memory for the window */
	if ( (current = malloc(sizeof(windowtype))) == NULL )
	{
		windowerr = WE_OMEM;
		return NULL;
	}

	/* Store the coorinates (including the border) */
	current->top	= --top;
	current->bottom = ++bottom;
	current->left	= --left;
	current->right	= ++right;

	/* Calculate the size of the back-buffer */
	current->size = size = ((bottom-top+1)*(right-left+1)) << 1;

	/* Allocate the memory for the back buffer */
	if ( (current->backbuffer = malloc(size)) == NULL )
	{
		windowerr = WE_OMEM;
		return NULL;
	}

	/* Store the cursor position for the current window */
	if (windowchain)
	{
		windowchain->xpos = wherex();
		windowchain->ypos = wherey();
	}
	else
	{
		xpos = wherex();
		ypos = wherey();
	}

	/* Store the screen image that we are going to write over */
	gettext(left,top,right,bottom,current->backbuffer);

	/* Draw the border */
	window(1,1,80,25);

	box(left,top,right,bottom,attr,style[the_style]);

	/* Set the writting attribute */
	textattr(attr);
	current->attr = attr;

	/* Center the title on the border */
	/*  If the title is too big for the border or it
	 *  is empty, don't write it
	 */
	if ( (len = strlen(title)) <= (right - left)   || len == 0 )
	{
		gotoxy( (right + left - len + 1) >> 1, top);
		cputs(title);
	}

	/* Section of the screen for the window */
	window(left+1,top+1,right-1,bottom-1);


	/* Register the window in the window chain, it becomes current */
	if (windowchain != NULL)
		windowchain->previous = current;
	current->next = windowchain;
	current->previous = NULL;
	windowchain = current;

	/* Return the window */
	return current;
}

char *backimage;
windowtype *imagefor;

/**************
FUNCTION: invalidate_backimage()
********************************/
void invalidate_backimage(void)
{
	if ( backimage )
	{
		free(backimage);
		backimage=NULL;
	}
}

/**********************
FUNCTION: deletewindow()
*************************/
/*	RETURN: 0 Success, -1 Failure. */
int deletewindow(windowtype *current)
{
	if (windowchain != current)
		return -1;

	invalidate_backimage();

	puttext(current->left,current->top,current->right,current->bottom,
		current->backbuffer);

	windowchain = current->next;
	free(current->backbuffer);
	free(current);
	if (windowchain != NULL)
		windowchain->previous = NULL;

	if (windowchain)
	{
		window(windowchain->left+1,windowchain->top+1,windowchain->right-1,
			   windowchain->bottom-1);
		gotoxy(windowchain->xpos, windowchain->ypos);
	}
	else
	{
		window(1,1,80,25);
		gotoxy(xpos,ypos);
	}
	return 0;
}

/*********************
FUNCTION: shiftwindow()
**********************/
/*	Make a window the current window.
 *	RETURN: 0 Success, 1 Out of memory
 */
int shiftwindow(windowtype *awindow)
{
	char *forscreen;

	/* If it is already the current window, we don't neeed to shift it */
	if (windowchain == awindow)
		return (int) windowerr = WE_OK;

	/* Store the current window's cursor coordinates */
	windowchain->xpos = wherex();
	windowchain->ypos = wherey();

	/* Get the image to place on the screen */
	if ( (forscreen = getwinimage(awindow,0)) == NULL )
	{
		free(forscreen);
		return (int) windowerr = WE_OMEM;
	}

	/* Distribute the backbuffer */
	if ( putwinimage(awindow,awindow->backbuffer,0,0) != 0 )
		return (int) windowerr = WE_OMEM;

	/* Delete the window from current position and insert it on top */
	if (awindow->next)
		awindow->next->previous = awindow->previous;
	if (awindow->previous)
		awindow->previous->next = awindow->next;

	if (windowchain != NULL )
		windowchain->previous = awindow;
	awindow->previous = NULL;
	awindow->next = windowchain;
	windowchain = awindow;

	/* Write the forscreen to the screen, this will actually "pop-up"
	 * the window.
	 */
	puttext(awindow->left,awindow->top,awindow->right,awindow->bottom,
			forscreen);

	/* Section off the screen for the window and put the cursor back
	 * where it was before the window was made non-current
	 */
	window(awindow->left+1,awindow->top+1,awindow->right-1,awindow->bottom-1);
	gotoxy(awindow->xpos,awindow->ypos);
	textattr(awindow->attr);

	/* Free allocated memory */
	free(forscreen);

	/* Tell the user everythings OK */
	return (int) windowerr = WE_OK;
}

static char *forimage;

/*****************
FUNCTION: putwinimage()
*********************/
int putwinimage(windowtype *window, char *image, unsigned off, int update)
{
	if ( !forimage )
	{
		if ( (forimage = malloc(window->size)) == NULL )
			return -1;
		gettext(window->left+off, window->top+off, window->right-off,
			window->bottom-off,forimage);
	}

	processimage(window, image, off, 1);

	ifn0move(forimage, image, window->size);

	if ( update )
		puttext(window->left+off, window->top+off, window->right-off,
			window->bottom-off,forimage);
	else
		memcpy(image, forimage, window->size);

	free(forimage);
	forimage = NULL;

	return 0;
}

/*******************
FUNCTION: getwinimage()
*************************/
char *getwinimage(windowtype *window, unsigned off)
{
	char *image;

	free(forimage);
	forimage = NULL;

	if ( (image = calloc(window->size,1)) == NULL )
		return NULL;

	if ( (forimage = malloc(window->size)) == NULL )
	{
		free(image);
		return NULL;
	}
	processimage(window, image, off, 0);

	gettext(window->left+off, window->top+off, window->right-off,
		window->bottom-off,forimage);
	if0move(image, forimage, window->size);

	return image;
}


/********************
FUNCTION: processimage()
*************************/
void processimage(windowtype *window, char *image, unsigned inset,
	int put)
{
	register unsigned t1,t2;
	windowtype *current = window->previous;
	unsigned top, bottom, left, right;
	unsigned off1, off2, len, t;

	while ( current )
	{
		if (
		(top	= ((t1=window->top+inset)	> (t2=current->top)	? t1 : t2)) <=
		(bottom = ((t1=window->bottom-inset) < (t2=current->bottom) ? t1 : t2)) &&
		(left	= ((t1=window->left+inset)   > (t2=current->left)   ? t1 : t2)) <=
		(right	= ((t1=window->right-inset)  < (t2=current->right)  ? t1 : t2)))
		{
			/* Update the forscreen and backscreen	  */
			/*   Calculate optimized index references */
			off1 = ((window->right-inset) - (window->left+inset) + 1) << 1;
			off2 = ((current->right) - (current->left) + 1) << 1;
			len = (right - left + 1) << 1;

			/* calculate move positions */
			t1 = (left - (window->left+inset)) << 1;
			t2 = (left - (current->left)) << 1;

			if ( (window->top+inset) == top)
				t2 += off2*(top - (current->top));
			else
				t1 += off1*(top - (window->top+inset));

			/*   Move the memory appropriately */
			for (t=top ; t <= bottom; t++)
			{
				if (put)
				{
					char *tmp = &image[t1];
					ifn0move(&current->backbuffer[t2],tmp,len);
					memset(tmp,'\0',len);
				}
				else
					if0move(&image[t1],&current->backbuffer[t2],len);
				t1 += off1;
				t2 += off2;
			}
		}
		current = current->previous;
	}
}

/*************
FUNCTION disk_space()
*************/
long disk_space(int drive_designator,int free_vs_total)
{
	/* free_vs_total is a flag to either get the free_space (1)
	 or total_space (2)
	 You will need to #include <dos.h> */

	long total_space, free_space, bytes_per_cluster;
	struct dfree dfinfo;
	getdfree(drive_designator, &dfinfo);

	if( dfinfo.df_sclus == NULL)
	{
		printf("Error in getdfree\n");
		exit(0);
	}

	bytes_per_cluster=(dfinfo.df_sclus*dfinfo.df_bsec);

	switch (free_vs_total)
	{
		case (1):
		{
		free_space=(dfinfo.df_avail*bytes_per_cluster);
		return(free_space);
		}
	case (2):
		{
		total_space=(dfinfo.df_total*bytes_per_cluster);
		return(total_space);
		}
	default:
		{
		printf("Second parameter to function disk_space was not 1 or 2\n");
		exit(1);
		}
	}  /* end of switch */
}

/*************** End of Program ****************/
